@@ -117,7 +117,8 @@ class OracleHook(DbApiHook):
         self.fetch_lobs = fetch_lobs
 
     def get_conn(self) -> oracledb.Connection:
-        """Get an Oracle connection object.
+        """
+        Get an Oracle connection object.
 
         Optional parameters for using a custom DSN connection (instead of using
         a server alias from tnsnames.ora) The dsn (data source name) is the TNS
@@ -255,7 +256,8 @@ class OracleHook(DbApiHook):
         replace: bool | None = False,
         **kwargs,
     ) -> None:
-        """Insert a collection of tuples into a table.
+        """
+        Insert a collection of tuples into a table.
 
         All data to insert are treated as one transaction. Changes from standard
         DbApiHook implementation:
@@ -272,8 +274,14 @@ class OracleHook(DbApiHook):
         :param commit_every: the maximum number of rows to insert in one transaction
             Default 1000, Set greater than 0.
             Set 1 to insert each row in each single transaction
-        :param replace: Whether to replace instead of insert
+        :param replace: Whether to replace instead of insert. Currently not implemented.
         """
+        if replace:
+            warnings.warn(
+                "Using 'replace=True' does not implement any replace functionality currently.",
+                category=UserWarning,
+                stacklevel=2,
+            )
         try:
             import numpy as np
         except ImportError:
@@ -320,8 +328,11 @@ class OracleHook(DbApiHook):
         rows: list[tuple],
         target_fields: list[str] | None = None,
         commit_every: int = 5000,
+        sequence_column: str | None = None,
+        sequence_name: str | None = None,
     ):
-        """Perform bulk inserts efficiently for Oracle DB.
+        """
+        Perform bulk inserts efficiently for Oracle DB.
 
         This uses prepared statements via `executemany()`. For best performance,
         pass in `rows` as an iterator.
@@ -333,6 +344,8 @@ class OracleHook(DbApiHook):
             If None, each rows should have some order as table columns name
         :param commit_every: the maximum number of rows to insert in one transaction
             Default 5000. Set greater than 0. Set 1 to insert each row in each transaction
+        :param sequence_column: the column name to which the sequence will be applied, default None.
+        :param sequence_name: the names of the sequence_name in the table, default None.
         """
         if not rows:
             raise ValueError("parameter rows could not be None or empty iterable")
@@ -341,11 +354,28 @@ class OracleHook(DbApiHook):
             self.set_autocommit(conn, False)
         cursor = conn.cursor()  # type: ignore[attr-defined]
         values_base = target_fields or rows[0]
-        prepared_stm = "insert into {tablename} {columns} values ({values})".format(
-            tablename=table,
-            columns="({})".format(", ".join(target_fields)) if target_fields else "",
-            values=", ".join(f":{i}" for i in range(1, len(values_base) + 1)),
-        )
+
+        if bool(sequence_column) ^ bool(sequence_name):
+            raise ValueError(
+                "Parameters 'sequence_column' and 'sequence_name' must be provided together or not at all."
+            )
+
+        if sequence_column and sequence_name:
+            prepared_stm = "insert into {tablename} {columns} values ({values})".format(
+                tablename=table,
+                columns="({})".format(", ".join([sequence_column] + target_fields))
+                if target_fields
+                else f"({sequence_column})",
+                values=", ".join(
+                    [f"{sequence_name}.NEXTVAL"] + [f":{i}" for i in range(1, len(values_base) + 1)]
+                ),
+            )
+        else:
+            prepared_stm = "insert into {tablename} {columns} values ({values})".format(
+                tablename=table,
+                columns="({})".format(", ".join(target_fields)) if target_fields else "",
+                values=", ".join(f":{i}" for i in range(1, len(values_base) + 1)),
+            )
         row_count = 0
         # Chunk the rows
         row_chunk = []
